@@ -7,12 +7,6 @@
 #include "IReferenceCounted.h"
 #include "IFileArchive.h"
 
-namespace irr
-{
-namespace video
-{
-class IVideoDriver;
-} // end namespace video
 namespace io
 {
 
@@ -154,4 +148,3 @@ public:
 };
 
 } // end namespace io
-} // end namespace irr
