@@ -4,6 +4,7 @@
 
 #include "CXMeshFileLoader.h"
 #include "SkinnedMesh.h"
+#include "Transform.h"
 #include "os.h"
 
 #include "fast_atof.h"
@@ -23,8 +24,6 @@
 		return false;        \
 	} while (0)
 
-namespace irr
-{
 namespace scene
 {
 
@@ -54,7 +53,7 @@ IAnimatedMesh *CXMeshFileLoader::createMesh(io::IReadFile *file)
 	u32 time = os::Timer::getRealTime();
 #endif
 
-	AnimatedMesh = new SkinnedMeshBuilder();
+	AnimatedMesh = new SkinnedMeshBuilder(SkinnedMesh::SourceFormat::X);
 
 	SkinnedMesh *res = nullptr;
 	if (load(file)) {
@@ -513,6 +512,7 @@ bool CXMeshFileLoader::parseDataObjectFrame(SkinnedMesh::SJoint *Parent)
 		if (n.has_value()) {
 			JointID = *n;
 			joint = AnimatedMesh->getAllJoints()[JointID];
+			joint->setParent(Parent);
 		}
 	}
 
@@ -527,8 +527,6 @@ bool CXMeshFileLoader::parseDataObjectFrame(SkinnedMesh::SJoint *Parent)
 #ifdef _XREADER_DEBUG
 		os::Printer::log("using joint ", name.c_str(), ELL_DEBUG);
 #endif
-		if (Parent)
-			Parent->Children.push_back(joint);
 	}
 
 	// Now inside a frame.
@@ -552,12 +550,10 @@ bool CXMeshFileLoader::parseDataObjectFrame(SkinnedMesh::SJoint *Parent)
 			if (!parseDataObjectFrame(joint))
 				return false;
 		} else if (objectName == "FrameTransformMatrix") {
-			if (!parseDataObjectTransformationMatrix(joint->LocalMatrix))
+			core::matrix4 matrix;
+			if (!parseDataObjectTransformationMatrix(matrix))
 				return false;
-
-			// joint->LocalAnimatedMatrix
-			// joint->LocalAnimatedMatrix.makeInverse();
-			// joint->LocalMatrix=tmp*joint->LocalAnimatedMatrix;
+			joint->transform = matrix;
 		} else if (objectName == "Mesh") {
 			/*
 			frame.Meshes.push_back(SXMesh());
@@ -1338,7 +1334,7 @@ bool CXMeshFileLoader::parseDataObjectAnimationTicksPerSecond()
 		SET_ERR_AND_RETURN();
 	}
 
-	AnimatedMesh->setAnimationSpeed(static_cast<irr::f32>(ticks));
+	AnimatedMesh->setAnimationSpeed(static_cast<f32>(ticks));
 
 	return true;
 }
@@ -1526,8 +1522,6 @@ bool CXMeshFileLoader::parseDataObjectAnimationKey(SkinnedMesh::SJoint *joint)
 				os::Printer::log("Line", core::stringc(Line).c_str(), ELL_WARNING);
 			}
 
-			// core::vector3df rotation = mat.getRotationDegrees();
-
 			AnimatedMesh->addRotationKey(joint, time, core::quaternion(mat.getTransposed()));
 			AnimatedMesh->addPositionKey(joint, time, mat.getTranslation());
 
@@ -2008,4 +2002,3 @@ bool CXMeshFileLoader::readMatrix(core::matrix4 &mat)
 }
 
 } // end namespace scene
-} // end namespace irr
